# Awesome CLI

Say <span style="color: #800000; text-decoration-color: #800000; font-weight: bold">hello</span> to the user.

**Usage**:

```console
$ hello [OPTIONS] USER_1 [USER_2]
```

**Arguments**:

* `USER_1`: The <span style="font-weight: bold">cool</span> name of the <span style="color: #008000; text-decoration-color: #008000">user</span>  [required]
* `[USER_2]`: The world  [default: The World]

**Options**:

* `--force / --no-force`: Force the welcome <span style="color: #800000; text-decoration-color: #800000">message</span>  [default: no-force]
* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.
